==> jc-1.4.0.tar.gz: gnu/java/nio/DatagramChannelSelectionKey.h <==
// public final class gnu.java.nio.DatagramChannelSelectionKey

// class file dependencies
// @dep_class 2a40c36b5ef968ab gnu_java_nio_DatagramChannelSelectionKey
// @dep_class b28d29aeeb71c32a gnu_java_nio_SelectionKeyImpl
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 78dea1137fb244b3 java_nio_channels_SelectionKey
// @dep_class c9ba919e4c66ad44 java_nio_channels_spi_AbstractSelectionKey

// header file dependencies
// @dep_header gnu_java_nio_SelectionKeyImpl

#include "gnu/java/nio/SelectionKeyImpl.h"

#ifndef _JC_gnu_java_nio_DatagramChannelSelectionKey_H_
#define _JC_gnu_java_nio_DatagramChannelSelectionKey_H_

// Forward structure declarations
struct _jc_gnu_java_nio_SelectorImpl$object;
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_spi_AbstractSelectableChannel$object;

// Typedefs
typedef struct _jc_gnu_java_nio_DatagramChannelSelectionKey$sub_refs	_jc_gnu_java_nio_DatagramChannelSelectionKey$sub_refs;
typedef struct _jc_gnu_java_nio_DatagramChannelSelectionKey$sub_nonrefs	_jc_gnu_java_nio_DatagramChannelSelectionKey$sub_nonrefs;
typedef struct _jc_gnu_java_nio_DatagramChannelSelectionKey$refs	_jc_gnu_java_nio_DatagramChannelSelectionKey$refs;
typedef struct _jc_gnu_java_nio_DatagramChannelSelectionKey$nonrefs	_jc_gnu_java_nio_DatagramChannelSelectionKey$nonrefs;
typedef struct _jc_gnu_java_nio_DatagramChannelSelectionKey$object	_jc_gnu_java_nio_DatagramChannelSelectionKey$object;

typedef const struct _jc_gnu_java_nio_DatagramChannelSelectionKey$vmethods	_jc_gnu_java_nio_DatagramChannelSelectionKey$vmethods;
typedef const struct _jc_gnu_java_nio_DatagramChannelSelectionKey$vtable	_jc_gnu_java_nio_DatagramChannelSelectionKey$vtable;
typedef const struct _jc_gnu_java_nio_DatagramChannelSelectionKey$vtype	_jc_gnu_java_nio_DatagramChannelSelectionKey$vtype;

// Constructors
extern void _jc_gnu_java_nio_DatagramChannelSelectionKey$method$_init$57e773c5fdc3e0ed(_jc_env *, struct _jc_gnu_java_nio_DatagramChannelSelectionKey$object *, struct _jc_java_nio_channels_spi_AbstractSelectableChannel$object *, struct _jc_gnu_java_nio_SelectorImpl$object *);

// Virtual methods
extern jint _jc_gnu_java_nio_DatagramChannelSelectionKey$method$getNativeFD$4ed008ed25fb0a89(_jc_env *, struct _jc_gnu_java_nio_DatagramChannelSelectionKey$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_DatagramChannelSelectionKey$method_info$getNativeFD$4ed008ed25fb0a89;

// Virtual methods structure
struct _jc_gnu_java_nio_DatagramChannelSelectionKey$vmethods {
	jint	(*getNativeFD$4ed008ed25fb0a89)(_jc_env *, struct _jc_gnu_java_nio_DatagramChannelSelectionKey$object *);
};

// Vtable
struct _jc_gnu_java_nio_DatagramChannelSelectionKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_SelectionKey$vmethods	java_nio_channels_SelectionKey;
	_jc_java_nio_channels_spi_AbstractSelectionKey$vmethods	java_nio_channels_spi_AbstractSelectionKey;
	_jc_gnu_java_nio_SelectionKeyImpl$vmethods	gnu_java_nio_SelectionKeyImpl;
	_jc_gnu_java_nio_DatagramChannelSelectionKey$vmethods	gnu_java_nio_DatagramChannelSelectionKey;
};

// Vtype
struct _jc_gnu_java_nio_DatagramChannelSelectionKey$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_DatagramChannelSelectionKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_DatagramChannelSelectionKey$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_DatagramChannelSelectionKey$refs {
    _jc_gnu_java_nio_DatagramChannelSelectionKey$sub_refs	gnu_java_nio_DatagramChannelSelectionKey;
    _jc_gnu_java_nio_SelectionKeyImpl$sub_refs	gnu_java_nio_SelectionKeyImpl;
    _jc_java_nio_channels_spi_AbstractSelectionKey$sub_refs	java_nio_channels_spi_AbstractSelectionKey;
    _jc_java_nio_channels_SelectionKey$sub_refs	java_nio_channels_SelectionKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_DatagramChannelSelectionKey$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_DatagramChannelSelectionKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_SelectionKey$sub_nonrefs	java_nio_channels_SelectionKey;
    _jc_java_nio_channels_spi_AbstractSelectionKey$sub_nonrefs	java_nio_channels_spi_AbstractSelectionKey;
    _jc_gnu_java_nio_SelectionKeyImpl$sub_nonrefs	gnu_java_nio_SelectionKeyImpl;
    _jc_gnu_java_nio_DatagramChannelSelectionKey$sub_nonrefs	gnu_java_nio_DatagramChannelSelectionKey;
};

// Object instance structure
struct _jc_gnu_java_nio_DatagramChannelSelectionKey$object {
	_jc_gnu_java_nio_DatagramChannelSelectionKey$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_DatagramChannelSelectionKey$vtype	*vtype;
	_jc_gnu_java_nio_DatagramChannelSelectionKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_DatagramChannelSelectionKey$vtype _jc_gnu_java_nio_DatagramChannelSelectionKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_DatagramChannelSelectionKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_DatagramChannelSelectionKey$class_object;

#endif	/* _JC_gnu_java_nio_DatagramChannelSelectionKey_H_ */

==> jc-1.4.5.tar.gz: gnu/java/nio/DatagramChannelSelectionKey.h <==
// public final class gnu.java.nio.DatagramChannelSelectionKey

// class file dependencies
// @dep_class 2a40c36b5ef968ab gnu_java_nio_DatagramChannelSelectionKey
// @dep_class b28d29aeeb71c32a gnu_java_nio_SelectionKeyImpl
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 78dea1137fb244b3 java_nio_channels_SelectionKey
// @dep_class c9ba919e4c66ad44 java_nio_channels_spi_AbstractSelectionKey

// header file dependencies
// @dep_header gnu_java_nio_SelectionKeyImpl

#include "gnu/java/nio/SelectionKeyImpl.h"

#ifndef _JC_gnu_java_nio_DatagramChannelSelectionKey_H_
#define _JC_gnu_java_nio_DatagramChannelSelectionKey_H_

// Forward structure declarations
struct _jc_gnu_java_nio_SelectorImpl$object;
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_spi_AbstractSelectableChannel$object;

// Typedefs
typedef struct _jc_gnu_java_nio_DatagramChannelSelectionKey$sub_refs	_jc_gnu_java_nio_DatagramChannelSelectionKey$sub_refs;
typedef struct _jc_gnu_java_nio_DatagramChannelSelectionKey$sub_nonrefs	_jc_gnu_java_nio_DatagramChannelSelectionKey$sub_nonrefs;
typedef struct _jc_gnu_java_nio_DatagramChannelSelectionKey$refs	_jc_gnu_java_nio_DatagramChannelSelectionKey$refs;
typedef struct _jc_gnu_java_nio_DatagramChannelSelectionKey$nonrefs	_jc_gnu_java_nio_DatagramChannelSelectionKey$nonrefs;
typedef struct _jc_gnu_java_nio_DatagramChannelSelectionKey$object	_jc_gnu_java_nio_DatagramChannelSelectionKey$object;

typedef const struct _jc_gnu_java_nio_DatagramChannelSelectionKey$vmethods	_jc_gnu_java_nio_DatagramChannelSelectionKey$vmethods;
typedef const struct _jc_gnu_java_nio_DatagramChannelSelectionKey$vtable	_jc_gnu_java_nio_DatagramChannelSelectionKey$vtable;
typedef const struct _jc_gnu_java_nio_DatagramChannelSelectionKey$vtype	_jc_gnu_java_nio_DatagramChannelSelectionKey$vtype;

// Constructors
extern void _jc_gnu_java_nio_DatagramChannelSelectionKey$method$_init$57e773c5fdc3e0ed(_jc_env *, struct _jc_gnu_java_nio_DatagramChannelSelectionKey$object *, struct _jc_java_nio_channels_spi_AbstractSelectableChannel$object *, struct _jc_gnu_java_nio_SelectorImpl$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_java_nio_DatagramChannelSelectionKey$method$getNativeFD$4ed008ed25fb0a89(_jc_env *, struct _jc_gnu_java_nio_DatagramChannelSelectionKey$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_DatagramChannelSelectionKey$method_info$getNativeFD$4ed008ed25fb0a89;

// Virtual methods structure
struct _jc_gnu_java_nio_DatagramChannelSelectionKey$vmethods {
	jint	(*getNativeFD$4ed008ed25fb0a89)(_jc_env *, struct _jc_gnu_java_nio_DatagramChannelSelectionKey$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_nio_DatagramChannelSelectionKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_SelectionKey$vmethods	java_nio_channels_SelectionKey;
	_jc_java_nio_channels_spi_AbstractSelectionKey$vmethods	java_nio_channels_spi_AbstractSelectionKey;
	_jc_gnu_java_nio_SelectionKeyImpl$vmethods	gnu_java_nio_SelectionKeyImpl;
	_jc_gnu_java_nio_DatagramChannelSelectionKey$vmethods	gnu_java_nio_DatagramChannelSelectionKey;
};

// Vtype
struct _jc_gnu_java_nio_DatagramChannelSelectionKey$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_DatagramChannelSelectionKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_DatagramChannelSelectionKey$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_DatagramChannelSelectionKey$refs {
    _jc_gnu_java_nio_DatagramChannelSelectionKey$sub_refs	gnu_java_nio_DatagramChannelSelectionKey;
    _jc_gnu_java_nio_SelectionKeyImpl$sub_refs	gnu_java_nio_SelectionKeyImpl;
    _jc_java_nio_channels_spi_AbstractSelectionKey$sub_refs	java_nio_channels_spi_AbstractSelectionKey;
    _jc_java_nio_channels_SelectionKey$sub_refs	java_nio_channels_SelectionKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_DatagramChannelSelectionKey$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_DatagramChannelSelectionKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_SelectionKey$sub_nonrefs	java_nio_channels_SelectionKey;
    _jc_java_nio_channels_spi_AbstractSelectionKey$sub_nonrefs	java_nio_channels_spi_AbstractSelectionKey;
    _jc_gnu_java_nio_SelectionKeyImpl$sub_nonrefs	gnu_java_nio_SelectionKeyImpl;
    _jc_gnu_java_nio_DatagramChannelSelectionKey$sub_nonrefs	gnu_java_nio_DatagramChannelSelectionKey;
};

// Object instance structure
struct _jc_gnu_java_nio_DatagramChannelSelectionKey$object {
	_jc_gnu_java_nio_DatagramChannelSelectionKey$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_DatagramChannelSelectionKey$vtype	*vtype;
	_jc_gnu_java_nio_DatagramChannelSelectionKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_DatagramChannelSelectionKey$vtype _jc_gnu_java_nio_DatagramChannelSelectionKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_DatagramChannelSelectionKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_DatagramChannelSelectionKey$class_object;

#endif	/* _JC_gnu_java_nio_DatagramChannelSelectionKey_H_ */
